@@ -306,7 +306,7 @@ pop_and_extract (void)
 		
     /* Update the progress bars */
     gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress_bar),
-                                   CLAMP (1.0 - ((g_list_length (pending) + 1)  / (float)total_extracting), 0.0, 1.0));
+                                   CLAMP ((float)current_duration / (float)total_duration, 0.0, 1.0));
 
     /* Now actually do the extraction */
     sj_extractor_extract_track (extractor, track, file_path, &error);
@@ -491,12 +491,15 @@ show_finished_dialog (void)
 static void
 on_completion_cb (SjExtractor *extractor, gpointer data)
 {
-  gtk_list_store_set (track_store, &track->iter,
-                    COLUMN_STATE, STATE_IDLE, -1);
+  /* Only manipulate the track state if we have an album, as we might be here if
+     the disk was ejected mid-rip. */
+  if (gtk_tree_model_iter_n_children (GTK_TREE_MODEL (track_store), NULL) > 0) {
+    /* Remove the track state */
+    gtk_list_store_set (track_store, &track->iter, COLUMN_STATE, STATE_IDLE, -1);
+    /* Uncheck the Extract check box */
+    gtk_list_store_set (track_store, &track->iter, COLUMN_EXTRACT, FALSE, -1);
+  }
   
-  /* Uncheck the Extract check box */
-  gtk_list_store_set (track_store, &track->iter, COLUMN_EXTRACT, FALSE, -1);
-
   if (pending == NULL) {
     show_finished_dialog ();
     if (autostart) {
